Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1695)

Unified Diff: chrome/browser/download/chrome_download_manager_delegate.cc

Issue 352393002: Be explicit about target type in platform_util::OpenItem() (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Simplify Chrome OS change. Created 6 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/download/chrome_download_manager_delegate.cc
diff --git a/chrome/browser/download/chrome_download_manager_delegate.cc b/chrome/browser/download/chrome_download_manager_delegate.cc
index 67bf169c9a22414225b88cba616c557718677710..b2d53737d657ade4ec8c6f9008dbb6861402c5fe 100644
--- a/chrome/browser/download/chrome_download_manager_delegate.cc
+++ b/chrome/browser/download/chrome_download_manager_delegate.cc
@@ -101,8 +101,9 @@ enum PlatformDownloadPathType {
PLATFORM_CURRENT_PATH
};
// Returns a path in the form that that is expected by platform_util::OpenItem /
// platform_util::ShowItemInFolder / DownloadTargetDeterminer.
//
// DownloadItems corresponding to Drive downloads use a temporary file as the
// target path. The paths returned by DownloadItem::GetFullPath() /
@@ -420,7 +421,7 @@ void ChromeDownloadManagerDelegate::OpenDownloadUsingPlatformHandler(
base::FilePath platform_path(
GetPlatformDownloadPath(profile_, download, PLATFORM_TARGET_PATH));
DCHECK(!platform_path.empty());
- platform_util::OpenItem(profile_, platform_path);
+ platform_util::OpenFile(profile_, platform_path);
}
void ChromeDownloadManagerDelegate::OpenDownload(DownloadItem* download) {
@@ -101,8 +101,9 @@ enum PlatformDownloadPathType {
PLATFORM_CURRENT_PATH
};
-// Returns a path in the form that that is expected by platform_util::OpenItem /
-// platform_util::ShowItemInFolder / DownloadTargetDeterminer.
+// Returns a path in the form that that is expected by platform_util::OpenFile /
+// platform_util::OpenFolder / platform_util::ShowItemInFolder /
+// DownloadTargetDeterminer.
//
// DownloadItems corresponding to Drive downloads use a temporary file as the

Powered by Google App Engine
This is Rietveld 408576698